Skip to contents

This class defines an DR meta-learner for the conditional relative average treatment effect (crr).

Format

An R6 class with public methods to initialize the learner, create a regression task, and access the base learner.

Super classes

sl3::Lrnr_base -> hte3::Lrnr_hte -> Lrnr_crr_DR_selector