Skip to contents

This class defines an efficient plug-in (EP) meta-learner for the conditional relative average treatment effect (crr).

Format

An R6 class with public methods to initialize the learner, create a regression task, and access the base learner.

Super classes

sl3::Lrnr_base -> hte3::Lrnr_hte -> Lrnr_crr_EP

Methods

Inherited methods


Method new()

Usage

Lrnr_crr_EP$new(
  base_learner,
  sieve_num_basis = NULL,
  sieve_interaction_order = 3,
  treatment_level = NULL,
  control_level = NULL,
  ...
)

Arguments

base_learner

A sl3 learner object inheriting from Lrnr_base that specifies the base supervised learning algorithm used by the meta-learner.

sieve_num_basis

The number of trigonometric basis functions used to construct the CRR EP sieve space through sieve_preprocess. Use sieve_num_basis for one fixed EP fit and sieve_basis_grid in fit_crr() for wrapper-level EP basis-size selection.

sieve_interaction_order

The maximum interaction degree of tensor-product basis functions in the EP sieve basis.

treatment_level

Optional treated level used for the contrast.

control_level

Optional control level used for the contrast.


Method get_pseudo_data()

Usage

Lrnr_crr_EP$get_pseudo_data(
  hte3_task,
  treatment_level = NULL,
  control_level = NULL,
  train = TRUE,
  ...
)

Arguments

treatment_level

Optional treated level used for the contrast.

control_level

Optional control level used for the contrast.


Method clone()

The objects of this class are cloneable with this method.

Usage

Lrnr_crr_EP$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.