This class defines an efficient plug-in (EP) meta-learner for the conditional relative average treatment effect (crr).
Format
An R6 class with public methods to initialize the learner, create a regression task, and access the base learner.
Super classes
sl3::Lrnr_base -> hte3::Lrnr_hte -> Lrnr_crr_EP
Methods
Inherited methods
sl3::Lrnr_base$assert_trained()sl3::Lrnr_base$base_chain()sl3::Lrnr_base$base_predict()sl3::Lrnr_base$base_train()sl3::Lrnr_base$chain()sl3::Lrnr_base$custom_chain()sl3::Lrnr_base$get_outcome_range()sl3::Lrnr_base$get_outcome_type()sl3::Lrnr_base$predict()sl3::Lrnr_base$predict_fold()sl3::Lrnr_base$print()sl3::Lrnr_base$process_formula()sl3::Lrnr_base$reparameterize()sl3::Lrnr_base$retrain()sl3::Lrnr_base$sample()sl3::Lrnr_base$set_train()sl3::Lrnr_base$subset_covariates()sl3::Lrnr_base$train()sl3::Lrnr_base$train_sublearners()hte3::Lrnr_hte$check_treatment_type()hte3::Lrnr_hte$get_modifiers()hte3::Lrnr_hte$make_metalearner_task()
Method new()
Usage
Lrnr_crr_EP$new(
base_learner,
sieve_num_basis = NULL,
sieve_interaction_order = 3,
treatment_level = NULL,
control_level = NULL,
...
)Arguments
base_learnerA
sl3learner object inheriting fromLrnr_basethat specifies the base supervised learning algorithm used by the meta-learner.sieve_num_basisThe number of trigonometric basis functions used to construct the CRR EP sieve space through
sieve_preprocess. Usesieve_num_basisfor one fixed EP fit andsieve_basis_gridinfit_crr()for wrapper-level EP basis-size selection.sieve_interaction_orderThe maximum interaction degree of tensor-product basis functions in the EP sieve basis.
treatment_levelOptional treated level used for the contrast.
control_levelOptional control level used for the contrast.