This class serves as a general template for constructing meta-learners to estimate heterogeneous treatment effects (HTEs).
Format
An R6 class with public methods to initialize the learner, create a regression task, and access the base learner.
Super class
sl3::Lrnr_base -> Lrnr_hte
Methods
Inherited methods
sl3::Lrnr_base$assert_trained()sl3::Lrnr_base$base_chain()sl3::Lrnr_base$base_predict()sl3::Lrnr_base$base_train()sl3::Lrnr_base$chain()sl3::Lrnr_base$custom_chain()sl3::Lrnr_base$get_outcome_range()sl3::Lrnr_base$get_outcome_type()sl3::Lrnr_base$predict()sl3::Lrnr_base$predict_fold()sl3::Lrnr_base$print()sl3::Lrnr_base$process_formula()sl3::Lrnr_base$reparameterize()sl3::Lrnr_base$retrain()sl3::Lrnr_base$sample()sl3::Lrnr_base$set_train()sl3::Lrnr_base$subset_covariates()sl3::Lrnr_base$train()sl3::Lrnr_base$train_sublearners()
Method new()
Arguments
paramsA list of parameters for the meta-learning algorithm.
base_learnerA
sl3learner object inheriting fromLrnr_basethat specifies the base supervised learning algorithm used by the meta-learner.transform_functionA function to transform the predictions of the base learner. Default is the identity transform.
pseudo_outcome_typeThe outcome type of the pseudo-outcome used by the meta-learner. Options are
c("continuous", "binomial", "quasibinomial"). Default is"continuous". For example, the DR-learner, EP-learner, and R-learner of the CATE involve (weighted) least-squares regression using a pseudo-outcome withpseudo_outcome_type = "continuous". The CRATE EP-learner involves performing weighted logistic regression using a pseudo-outcome taking values in 0,1 withpseudo_outcome_type = "quasibinomial".pseudo_familyA
familyobject specifying the loss function (involving pseudo-weights and pseudo-outcomes) used to fitbase_learnerin the meta-learner algorithm. Default isgaussian().
Method get_pseudo_data()
Method make_metalearner_task()
Arguments
hte3_taskA
hte3_Taskobject containing the data and necessary information for heterogeneous treatment effect estimation.trainLogical indicating whether to create the task for training or prediction. Default is
TRUE. IfFALSEthen ahte3_Taskobject for prediction is returned with covariates being the effectmodifiers.