Skip to contents

Internal use. Converts a single outcome learner into a multivariate outcome learner that predicts a matrix of predictions obtained by evaluating the single outcome learner at each possible value of variable_stratify.

Internal use. Converts a single outcome learner into a multivariate outcome learner that predicts a matrix of predictions obtained by evaluating the single outcome learner at each possible value of variable_stratify.

Super classes

sl3::Lrnr_base -> sl3::Lrnr_stratified -> Lrnr_stratified_multivariate