Constructs a hte3_Task object for meta-learners in causal data structures, containing relevant data and nuisance function estimators.
Details
Class for Storing Data, NPSEM, and Nuisance Function Estimators for hte3 Learners
This class inherits from sl3_Task and tmle3_Task.
In addition to all the methods supported by sl3_Task and tmle3_Task,
it supports the following functionalities specific to the heterogeneous treatment effect estimation (hte3) framework.
Super classes
sl3::sl3_Task -> tmle3::tmle3_Task -> hte3_Task
Methods
Inherited methods
sl3::sl3_Task$add_columns()sl3::sl3_Task$add_interactions()sl3::sl3_Task$get_data()sl3::sl3_Task$get_folds()sl3::sl3_Task$get_node()sl3::sl3_Task$has_node()sl3::sl3_Task$offset_transformed()sl3::sl3_Task$revere_fold_task()tmle3::tmle3_Task$generate_counterfactual_task()tmle3::tmle3_Task$get_node_bounds()tmle3::tmle3_Task$get_regression_task()tmle3::tmle3_Task$get_tmle_node()tmle3::tmle3_Task$print()tmle3::tmle3_Task$scale()tmle3::tmle3_Task$unscale()
Method new()
Usage
hte3_Task$new(data, npsem, likelihood = NULL, ...)Arguments
dataA named data frame or data.table containing treatment effect modifiers, potential confounders, treatment, outcome, and optionally weights and subject IDs. See the
sl3_Taskdocumentation for further options.npsemA list containing
tmle3_Nodeobjects containing the non-parametric structural equation model (NPSEM) specifying the relationship between variables in the treatment effect estimation framework.likelihoodAn
Likelihoodobject specifying the relevant likelihood/nuisance estimators for the meta-learner. used for estimating the parameters of the NPSEM....Additional arguments to pass to the initialization function.