S3 Methods for Production hte3 Models
hte3_model.RdThese methods provide the default prediction and summary interface for the
production hte3_model wrapper class.
Arguments
- object
An object created by
fit_cate()orfit_crr().- new_data
Optional prediction data. If omitted, predictions are returned on the training task.
- ...
Unused additional arguments.